@@ -491,11 +491,11 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
             else:
                 # has address with our prefix and MAC
                 expected_ip_a.append(
-                    "inet6 2600::[0-9a-f:]+/64 scope global (?:tentative )?(?:mngtmpaddr )?(?:noprefixroute )?(dynamic|\n\s*valid_lft forever preferred_lft forever)"
+                    r"inet6 2600::[0-9a-f:]+/64 scope global (?:tentative )?(?:mngtmpaddr )?(?:noprefixroute )?(dynamic|\n\s*valid_lft forever preferred_lft forever)"
                 )
                 # has address with our prefix and random IP (Privacy
                 # Extension), if requested
-                priv_re = "inet6 2600:[0-9a-f:]+/64 scope global temporary (?:tentative )?(?:mngtmpaddr )?dynamic"
+                priv_re = r"inet6 2600:[0-9a-f:]+/64 scope global temporary (?:tentative )?(?:mngtmpaddr )?dynamic"
                 if ip6_privacy in (
                     NM.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR,
                     NM.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR,
@@ -507,9 +507,9 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
                     # unexpected_ip_a.append(priv_re)
 
             # has a link-local address
-            expected_ip_a.append("inet6 fe80::[0-9a-f:]+/64 scope link")
+            expected_ip_a.append(r"inet6 fe80::[0-9a-f:]+/64 scope link")
         else:
-            expected_ip_a.append("inet 192.168.5.\d+/24")
+            expected_ip_a.append(r"inet 192.168.5.\d+/24")
 
         self.assert_iface_up(iface, expected_ip_a, unexpected_ip_a)
 
@@ -764,7 +764,7 @@ ctrl_interface_group=0
         )
 
         # dev_w_client should be back up
-        self.assert_iface_up(self.dev_w_client, ["inet 192.168.5.\d+/24"])
+        self.assert_iface_up(self.dev_w_client, [r"inet 192.168.5.\d+/24"])
 
     #
     # Common test code
@@ -1096,13 +1096,13 @@ class Suspend(NetworkManagerTest, DBusTestCase):
         """suspend during active IPv4 connection"""
 
         self.do_test(
-            "hw_mode=b\nchannel=1\nssid=" + SSID, None, ["inet 192.168.5.\d+/24"]
+            "hw_mode=b\nchannel=1\nssid=" + SSID, None, [r"inet 192.168.5.\d+/24"]
         )
 
     def fixme_test_active_ip6(self):
         """suspend during active IPv6 connection"""
 
-        self.do_test("hw_mode=b\nchannel=1\nssid=" + SSID, "ra-only", ["inet6 2600::"])
+        self.do_test("hw_mode=b\nchannel=1\nssid=" + SSID, "ra-only", [r"inet6 2600::"])
 
     #
     # Common test code
